@@ -1,4 +1,4 @@
-`poLCA.updatePrior` <-
+poLCA.updatePrior <-
 function(b,x,R) {
     b <- matrix(b,ncol=(R-1))
     exb <- exp(x %*% b)
